All of lore.kernel.org
 help / color / mirror / Atom feed
From: Tejun Heo <tj@kernel.org>
To: axboe@kernel.dk
Cc: linux-kernel@vger.kernel.org, lizefan@huawei.com,
	containers@lists.linux-foundation.org, cgroups@vger.kernel.org,
	vgoyal@redhat.com, Tejun Heo <tj@kernel.org>
Subject: [PATCH 11/31] blk-throttle: rename throtl_rb_root to throtl_service_queue
Date: Wed,  1 May 2013 17:39:29 -0700	[thread overview]
Message-ID: <1367455189-6957-12-git-send-email-tj@kernel.org> (raw)
In-Reply-To: <1367455189-6957-1-git-send-email-tj@kernel.org>

throtl_rb_root will be expanded to cover more roles for hierarchy
support.  Rename it to throtl_service_queue and make its fields more
descriptive.

* rb		-> pending_tree
* left		-> first_pending
* count		-> nr_pending
* min_disptime	-> first_pending_disptime

This patch is purely cosmetic.

Signed-off-by: Tejun Heo <tj@kernel.org
---
 block/blk-throttle.c | 84 ++++++++++++++++++++++++++--------------------------
 1 file changed, 42 insertions(+), 42 deletions(-)

diff --git a/block/blk-throttle.c b/block/blk-throttle.c
index 6fd08a4..6723ca2 100644
--- a/block/blk-throttle.c
+++ b/block/blk-throttle.c
@@ -26,15 +26,15 @@ static struct blkcg_policy blkcg_policy_throtl;
 /* A workqueue to queue throttle related work */
 static struct workqueue_struct *kthrotld_workqueue;
 
-struct throtl_rb_root {
-	struct rb_root rb;
-	struct rb_node *left;
-	unsigned int count;
-	unsigned long min_disptime;
+struct throtl_service_queue {
+	struct rb_root		pending_tree;	/* RB tree of active tgs */
+	struct rb_node		*first_pending;	/* first node in the tree */
+	unsigned int		nr_pending;	/* # queued in the tree */
+	unsigned long		first_pending_disptime;	/* disptime of the first tg */
 };
 
-#define THROTL_RB_ROOT	(struct throtl_rb_root) { .rb = RB_ROOT, .left = NULL, \
-			.count = 0, .min_disptime = 0}
+#define THROTL_SERVICE_QUEUE_INITIALIZER				\
+	(struct throtl_service_queue){ .pending_tree = RB_ROOT }
 
 #define rb_entry_tg(node)	rb_entry((node), struct throtl_grp, rb_node)
 
@@ -50,7 +50,7 @@ struct throtl_grp {
 	/* must be the first member */
 	struct blkg_policy_data pd;
 
 	/* active throtl group service_tree member */
 	struct rb_node rb_node;
 
 	/*
@@ -93,7 +93,7 @@ struct throtl_grp {
 struct throtl_data
 {
 	/* service tree for active throtl groups */
-	struct throtl_rb_root tg_service_tree;
+	struct throtl_service_queue service_queue;
 
 	struct request_queue *queue;
 
@@ -296,17 +296,17 @@ static struct throtl_grp *throtl_lookup_create_tg(struct throtl_data *td,
 	return tg;
 }
 
-static struct throtl_grp *throtl_rb_first(struct throtl_rb_root *root)
+static struct throtl_grp *throtl_rb_first(struct throtl_service_queue *sq)
 {
 	/* Service tree is empty */
-	if (!root->count)
+	if (!sq->nr_pending)
 		return NULL;
 
-	if (!root->left)
-		root->left = rb_first(&root->rb);
+	if (!sq->first_pending)
+		sq->first_pending = rb_first(&sq->pending_tree);
 
-	if (root->left)
-		return rb_entry_tg(root->left);
+	if (sq->first_pending)
+		return rb_entry_tg(sq->first_pending);
 
 	return NULL;
 }
@@ -317,29 +317,29 @@ static void rb_erase_init(struct rb_node *n, struct rb_root *root)
 	RB_CLEAR_NODE(n);
 }
 
-static void throtl_rb_erase(struct rb_node *n, struct throtl_rb_root *root)
+static void throtl_rb_erase(struct rb_node *n, struct throtl_service_queue *sq)
 {
-	if (root->left == n)
-		root->left = NULL;
-	rb_erase_init(n, &root->rb);
-	--root->count;
+	if (sq->first_pending == n)
+		sq->first_pending = NULL;
+	rb_erase_init(n, &sq->pending_tree);
+	--sq->nr_pending;
 }
 
-static void update_min_dispatch_time(struct throtl_rb_root *st)
+static void update_min_dispatch_time(struct throtl_service_queue *sq)
 {
 	struct throtl_grp *tg;
 
-	tg = throtl_rb_first(st);
+	tg = throtl_rb_first(sq);
 	if (!tg)
 		return;
 
-	st->min_disptime = tg->disptime;
+	sq->first_pending_disptime = tg->disptime;
 }
 
-static void
-tg_service_tree_add(struct throtl_rb_root *st, struct throtl_grp *tg)
+static void tg_service_queue_add(struct throtl_service_queue *sq,
+				 struct throtl_grp *tg)
 {
-	struct rb_node **node = &st->rb.rb_node;
+	struct rb_node **node = &sq->pending_tree.rb_node;
 	struct rb_node *parent = NULL;
 	struct throtl_grp *__tg;
 	unsigned long key = tg->disptime;
@@ -358,19 +358,19 @@ tg_service_tree_add(struct throtl_rb_root *st, struct throtl_grp *tg)
 	}
 
 	if (left)
-		st->left = &tg->rb_node;
+		sq->first_pending = &tg->rb_node;
 
 	rb_link_node(&tg->rb_node, parent, node);
-	rb_insert_color(&tg->rb_node, &st->rb);
+	rb_insert_color(&tg->rb_node, &sq->pending_tree);
 }
 
 static void __throtl_enqueue_tg(struct throtl_data *td, struct throtl_grp *tg)
 {
-	struct throtl_rb_root *st = &td->tg_service_tree;
+	struct throtl_service_queue *sq = &td->service_queue;
 
-	tg_service_tree_add(st, tg);
+	tg_service_queue_add(sq, tg);
 	throtl_mark_tg_on_rr(tg);
-	st->count++;
+	sq->nr_pending++;
 }
 
 static void throtl_enqueue_tg(struct throtl_data *td, struct throtl_grp *tg)
@@ -381,7 +381,7 @@ static void throtl_enqueue_tg(struct throtl_data *td, struct throtl_grp *tg)
 
 static void __throtl_dequeue_tg(struct throtl_data *td, struct throtl_grp *tg)
 {
-	throtl_rb_erase(&tg->rb_node, &td->tg_service_tree);
+	throtl_rb_erase(&tg->rb_node, &td->service_queue);
 	throtl_clear_tg_on_rr(tg);
 }
 
@@ -403,18 +403,18 @@ static void throtl_schedule_delayed_work(struct throtl_data *td,
 
 static void throtl_schedule_next_dispatch(struct throtl_data *td)
 {
-	struct throtl_rb_root *st = &td->tg_service_tree;
+	struct throtl_service_queue *sq = &td->service_queue;
 
 	/* any pending children left? */
-	if (!st->count)
+	if (!sq->nr_pending)
 		return;
 
-	update_min_dispatch_time(st);
+	update_min_dispatch_time(sq);
 
-	if (time_before_eq(st->min_disptime, jiffies))
+	if (time_before_eq(sq->first_pending_disptime, jiffies))
 		throtl_schedule_delayed_work(td, 0);
 	else
-		throtl_schedule_delayed_work(td, (st->min_disptime - jiffies));
+		throtl_schedule_delayed_work(td, sq->first_pending_disptime - jiffies);
 }
 
 static inline void
@@ -794,10 +794,10 @@ static int throtl_select_dispatch(struct throtl_data *td, struct bio_list *bl)
 {
 	unsigned int nr_disp = 0;
 	struct throtl_grp *tg;
-	struct throtl_rb_root *st = &td->tg_service_tree;
+	struct throtl_service_queue *sq = &td->service_queue;
 
 	while (1) {
-		tg = throtl_rb_first(st);
+		tg = throtl_rb_first(sq);
 
 		if (!tg)
 			break;
@@ -1148,7 +1148,7 @@ void blk_throtl_drain(struct request_queue *q)
 	__releases(q->queue_lock) __acquires(q->queue_lock)
 {
 	struct throtl_data *td = q->td;
-	struct throtl_rb_root *st = &td->tg_service_tree;
+	struct throtl_service_queue *sq = &td->service_queue;
 	struct throtl_grp *tg;
 	struct bio_list bl;
 	struct bio *bio;
@@ -1157,7 +1157,7 @@ void blk_throtl_drain(struct request_queue *q)
 
 	bio_list_init(&bl);
 
-	while ((tg = throtl_rb_first(st))) {
+	while ((tg = throtl_rb_first(sq))) {
 		throtl_dequeue_tg(td, tg);
 
 		while ((bio = bio_list_peek(&tg->bio_lists[READ])))
@@ -1182,7 +1182,7 @@ int blk_throtl_init(struct request_queue *q)
 	if (!td)
 		return -ENOMEM;
 
-	td->tg_service_tree = THROTL_RB_ROOT;
+	td->service_queue = THROTL_SERVICE_QUEUE_INITIALIZER;
 	INIT_DELAYED_WORK(&td->dispatch_work, blk_throtl_dispatch_work_fn);
 
 	q->td = td;
@@ -50,7 +50,7 @@ struct throtl_grp {
 	struct blkg_policy_data pd;
 
-	/* active throtl group service_tree member */
+	/* active throtl group service_queue member */
 	struct rb_node rb_node;
 
-- 
1.8.1.4

  reply	other threads:[~2013-05-02  0:39 UTC|newest]

Thread overview: 154+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2013-05-02  0:39 [PATCHSET] blk-throttle: implement proper hierarchy support Tejun Heo
2013-05-02  0:39 ` Tejun Heo
2013-05-02  0:39 ` Tejun Heo [this message]
     [not found] ` <1367455189-6957-1-git-send-email-tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>
2013-05-02  0:39   ` [PATCH 01/31] blkcg: fix error return path in blkg_create() Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 02/31] blkcg: move blkg_for_each_descendant_pre() to block/blk-cgroup.h Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 03/31] blkcg: implement blkg_for_each_descendant_post() Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 04/31] blkcg: invoke blkcg_policy->pd_init() after parent is linked Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 05/31] blkcg: move bulk of blkcg_gq release operations to the RCU callback Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 06/31] blk-throttle: remove spurious throtl_enqueue_tg() call from throtl_select_dispatch() Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` Tejun Heo
2013-05-02  0:39   ` [PATCH 07/31] blk-throttle: removed deferred config application mechanism Tejun Heo
2013-05-02  0:39     ` Tejun Heo
     [not found]     ` <1367455189-6957-8-git-send-email-tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>
2013-05-02 14:49       ` Vivek Goyal
2013-05-02 14:49         ` Vivek Goyal
     [not found]         ` <20130502144912.GE30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 17:27           ` Tejun Heo
2013-05-02 17:27             ` Tejun Heo
2013-05-02  0:39   ` [PATCH 08/31] blk-throttle: collapse throtl_dispatch() into the work function Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 09/31] blk-throttle: relocate throtl_schedule_delayed_work() Tejun Heo
2013-05-02  0:39   ` Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 10/31] blk-throttle: remove pointless throtl_nr_queued() optimizations Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 11/31] blk-throttle: rename throtl_rb_root to throtl_service_queue Tejun Heo
2013-05-02  0:39   ` [PATCH 12/31] blk-throttle: simplify throtl_grp flag handling Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 13/31] blk-throttle: add backlink pointer from throtl_grp to throtl_data Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 14/31] blk-throttle: pass around throtl_service_queue instead of throtl_data Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 15/31] blk-throttle: reorganize throtl_service_queue passed around as argument Tejun Heo
2013-05-02  0:39     ` Tejun Heo
     [not found]     ` <1367455189-6957-16-git-send-email-tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>
2013-05-02 15:21       ` Vivek Goyal
2013-05-02 15:21         ` Vivek Goyal
     [not found]         ` <20130502152148.GF30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 17:29           ` Tejun Heo
2013-05-02 17:29             ` Tejun Heo
2013-05-02  0:39   ` [PATCH 16/31] blk-throttle: add throtl_grp->service_queue Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 17/31] blk-throttle: move bio_lists[] and friends to throtl_service_queue Tejun Heo
2013-05-02  0:39   ` [PATCH 18/31] blk-throttle: dispatch to throtl_data->service_queue.bio_lists[] Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 19/31] blk-throttle: generalize update_disptime optimization in blk_throtl_bio() Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 20/31] blk-throttle: add throtl_service_queue->parent_sq Tejun Heo
2013-05-02  0:39   ` [PATCH 21/31] blk-throttle: implement sq_to_tg(), sq_to_td() and throtl_log() Tejun Heo
2013-05-02  0:39   ` [PATCH 22/31] blk-throttle: set REQ_THROTTLED from throtl_charge_bio() and gate stats update with it Tejun Heo
2013-05-02  0:39   ` [PATCH 23/31] blk-throttle: separate out throtl_service_queue->pending_timer from throtl_data->dispatch_work Tejun Heo
2013-05-02  0:39   ` [PATCH 24/31] blk-throttle: implement dispatch looping Tejun Heo
2013-05-02  0:39   ` [PATCH 25/31] blk-throttle: dispatch from throtl_pending_timer_fn() Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` Tejun Heo
2013-05-02  0:39   ` [PATCH 26/31] blk-throttle: make blk_throtl_drain() ready for hierarchy Tejun Heo
2013-05-02  0:39   ` [PATCH 27/31] blk-throttle: make blk_throtl_bio() " Tejun Heo
2013-05-02  0:39   ` [PATCH 28/31] blk-throttle: make tg_dispatch_one_bio() " Tejun Heo
2013-05-02  0:39   ` Tejun Heo
2013-05-02  0:39     ` Tejun Heo
2013-05-02  0:39   ` [PATCH 29/31] blk-throttle: make throtl_pending_timer_fn() " Tejun Heo
2013-05-02  0:39   ` [PATCH 30/31] blk-throttle: implement throtl_grp->has_rules[] Tejun Heo
2013-05-02  0:39   ` [PATCH 31/31] blk-throttle: implement proper hierarchy support Tejun Heo
2013-05-02 17:34   ` [PATCHSET] " Vivek Goyal
2013-05-02 17:34     ` Vivek Goyal
     [not found]     ` <20130502173428.GA4771-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 17:57       ` Tejun Heo
2013-05-02 17:57         ` Tejun Heo
     [not found]         ` <20130502175701.GL19814-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-02 18:17           ` Vivek Goyal
2013-05-02 18:17             ` Vivek Goyal
     [not found]             ` <20130502181747.GH30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 18:29               ` Tejun Heo
2013-05-02 18:29               ` Tejun Heo
2013-05-02 18:29                 ` Tejun Heo
     [not found]                 ` <20130502182933.GN19814-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-02 18:45                   ` Vivek Goyal
2013-05-02 18:45                     ` Vivek Goyal
     [not found]                     ` <20130502184514.GI30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 18:49                       ` Tejun Heo
2013-05-02 18:49                         ` Tejun Heo
     [not found]                         ` <20130502184953.GP19814-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-02 19:07                           ` Vivek Goyal
2013-05-02 19:07                             ` Vivek Goyal
     [not found]                             ` <20130502190732.GK30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 19:11                               ` Tejun Heo
2013-05-02 19:11                                 ` Tejun Heo
     [not found]                                 ` <CAOS58YOk7G=dBG1v5Ed2z3biMMyKkkutp30vH5XC72z0_Z85cw-JsoAwUIsXosN+BqQ9rBEUg@public.gmane.org>
2013-05-02 19:31                                   ` Vivek Goyal
2013-05-02 19:31                                   ` Vivek Goyal
2013-05-02 19:31                                     ` Vivek Goyal
     [not found]                                     ` <20130502193139.GL30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 23:13                                       ` Tejun Heo
2013-05-02 23:13                                         ` Tejun Heo
     [not found]                                         ` <20130502231307.GT19814-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-03 17:56                                           ` Vivek Goyal
2013-05-03 17:56                                             ` Vivek Goyal
     [not found]                                             ` <20130503175652.GB6062-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-03 18:57                                               ` Tejun Heo
2013-05-03 18:57                                                 ` Tejun Heo
     [not found]                                                 ` <20130503185751.GA22860-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-03 18:58                                                   ` Tejun Heo
2013-05-03 18:58                                                     ` Tejun Heo
2013-05-03 18:58                                                   ` Tejun Heo
2013-05-03 19:08                                                   ` Vivek Goyal
2013-05-03 19:08                                                     ` Vivek Goyal
     [not found]                                                     ` <20130503190823.GC6062-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-03 19:14                                                       ` Tejun Heo
2013-05-03 19:14                                                       ` Tejun Heo
2013-05-03 19:14                                                         ` Tejun Heo
     [not found]                                                         ` <20130503191418.GC22860-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-03 19:26                                                           ` Vivek Goyal
2013-05-03 19:26                                                             ` Vivek Goyal
2013-05-03 21:05                                                           ` Vivek Goyal
2013-05-03 21:05                                                             ` Vivek Goyal
     [not found]                                                             ` <20130503210513.GE6062-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-03 23:54                                                               ` Tejun Heo
2013-05-03 23:54                                                                 ` Tejun Heo
     [not found]                                                                 ` <20130503235455.GE22860-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-06 17:33                                                                   ` Vivek Goyal
2013-05-06 17:33                                                                     ` Vivek Goyal
2013-05-03 21:05                                                           ` Vivek Goyal
2013-05-03 19:08                                                   ` Vivek Goyal
2013-05-03 18:57                                               ` Tejun Heo
2013-05-03 17:56                                           ` Vivek Goyal
2013-05-02 18:49                       ` Tejun Heo
2013-05-02 17:57       ` Tejun Heo
2013-05-02 18:08       ` Vivek Goyal
2013-05-02 18:08         ` Vivek Goyal
     [not found]         ` <20130502180815.GG30020-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-02 18:44           ` Tejun Heo
2013-05-02 18:44             ` Tejun Heo
     [not found]             ` <20130502184426.GO19814-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-02 18:59               ` Vivek Goyal
2013-05-02 18:59                 ` Vivek Goyal
2013-05-02 18:59               ` Vivek Goyal
2013-05-04  0:50   ` [PATCH 29.5/32] blk-throttle: add throtl_qnode for dispatch fairness Tejun Heo
2013-05-04  0:50     ` Tejun Heo
     [not found]     ` <20130504005044.GF22860-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-04  0:53       ` Tejun Heo
2013-05-04  0:53         ` Tejun Heo
2013-05-06 16:00       ` Vivek Goyal
2013-05-06 16:00         ` Vivek Goyal
     [not found]         ` <20130506160006.GA11731-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-06 18:35           ` Tejun Heo
2013-05-06 18:35             ` Tejun Heo
2013-05-06 16:00       ` Vivek Goyal
2013-05-02  0:39 ` [PATCH 17/31] blk-throttle: move bio_lists[] and friends to throtl_service_queue Tejun Heo
2013-05-02  0:39 ` [PATCH 20/31] blk-throttle: add throtl_service_queue->parent_sq Tejun Heo
2013-05-02  0:39 ` [PATCH 21/31] blk-throttle: implement sq_to_tg(), sq_to_td() and throtl_log() Tejun Heo
     [not found]   ` <1367455189-6957-22-git-send-email-tj-DgEjT+Ai2ygdnm+yROfE0A@public.gmane.org>
2013-05-06 17:36     ` Vivek Goyal
2013-05-06 17:36       ` Vivek Goyal
     [not found]       ` <20130506173644.GD11731-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-06 18:38         ` Tejun Heo
2013-05-06 18:38           ` Tejun Heo
2013-05-06 20:38         ` Tejun Heo
2013-05-06 20:38           ` Tejun Heo
     [not found]           ` <20130506203827.GE800-9pTldWuhBndy/B6EtB590w@public.gmane.org>
2013-05-06 20:39             ` Tejun Heo
2013-05-06 20:39               ` Tejun Heo
2013-05-06 20:39             ` Tejun Heo
2013-05-06 20:41             ` Vivek Goyal
2013-05-06 20:41               ` Vivek Goyal
     [not found]               ` <20130506204141.GF11731-H+wXaHxf7aLQT0dZR+AlfA@public.gmane.org>
2013-05-06 20:43                 ` Tejun Heo
2013-05-06 20:43                   ` Tejun Heo
2013-05-06 20:43                 ` Tejun Heo
2013-05-02  0:39 ` [PATCH 22/31] blk-throttle: set REQ_THROTTLED from throtl_charge_bio() and gate stats update with it Tejun Heo
2013-05-02  0:39 ` [PATCH 23/31] blk-throttle: separate out throtl_service_queue->pending_timer from throtl_data->dispatch_work Tejun Heo
2013-05-02  0:39 ` [PATCH 24/31] blk-throttle: implement dispatch looping Tejun Heo
2013-05-02  0:39 ` [PATCH 26/31] blk-throttle: make blk_throtl_drain() ready for hierarchy Tejun Heo
2013-05-02  0:39 ` [PATCH 27/31] blk-throttle: make blk_throtl_bio() " Tejun Heo
2013-05-02  0:39 ` [PATCH 29/31] blk-throttle: make throtl_pending_timer_fn() " Tejun Heo
2013-05-02  0:39 ` [PATCH 30/31] blk-throttle: implement throtl_grp->has_rules[] Tejun Heo
2013-05-02  0:39 ` [PATCH 31/31] blk-throttle: implement proper hierarchy support Tejun Heo

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=1367455189-6957-12-git-send-email-tj@kernel.org \
    --to=tj@kernel.org \
    --cc=axboe@kernel.dk \
    --cc=cgroups@vger.kernel.org \
    --cc=containers@lists.linux-foundation.org \
    --cc=linux-kernel@vger.kernel.org \
    --cc=lizefan@huawei.com \
    --cc=vgoyal@redhat.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.